@@ -193,7 +193,7 @@ if(isset($_GET['action'])) {
 		//echo DEV_BINDING;
 		if(!$team_id){
 			$send[]=my_pack2(DEV_BINDING, $sim_name, $_POST[line_name]);
-			echo "1111111";
+			//echo "1111111";
 		}
 		else {
 			$send[]=my_pack2(DEV_BINDING, $sim_name, 0);
