@@ -37,6 +37,18 @@ if($_REQUEST['get']=='sim_line'){
 		echo "$row[0]\n";
 	}
 }
+elseif($_REQUEST['get']=='imsi'){
+	$query=$db->query("select sim_name,imsi from sim");
+	while($row=@$db->fetch_array($query)) {
+		echo "$row[0] $row[1]\n";
+	}
+}
+elseif($_REQUEST['get']=='iccid'){
+	$query=$db->query("select sim_name,iccid from sim");
+	while($row=@$db->fetch_array($query)) {
+		echo "$row[0] $row[1]\n";
+	}
+}
 elseif($_REQUEST['get']=='sim'){
         $query=$db->query("select sim_name from sim");
         while($row=@$db->fetch_array($query)) {
@@ -86,6 +98,33 @@ elseif($_REQUEST['set']=='bind'){
 	echo "OK.bind sim:$_REQUEST[sim]; line:$_REQUEST[line]";
         sendto_xchanged($send);
 }
+elseif($_REQUEST['set']=='group'){
+	if($_REQUEST['sim']) {
+		$query=$db->query("select id from scheduler_tem where name='$_REQUEST[group]'");
+		if($row=$db->fetch_array($query)){
+			$db->query("update sim set sim_team_id='$row[0]' where sim_name='$_REQUEST[sim]'");
+			//$send[]=my_pack2(DEV_BINDING, $_REQUEST['sim'], 0);
+			$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name where sim_name='$_REQUEST[sim]'");
+			$send[]=my_pack($row, SIM_ADD);
+			sendto_xchanged($send);
+			echo "OK";
+		}
+		else echo "ERROR group error!";
+	}
+	if($_REQUEST['line']) {
+		$query=$db->query("select id from scheduler_tem where name='$_REQUEST[group]'");
+		if($row=$db->fetch_array($query)){
+			$db->query("update device_line set goip_team_id='$row[0]' where line_name='$_REQUEST[line]'");
+			//$send[]=my_pack2(DEV_BINDING, $_REQUEST['sim'], 0);
+			$query=$db->query("select device_line.*,password,zone from device_line left join rm_device on device_line.goip_name = rm_device.name where line_name='$_REQUEST[line]'");
+			$send[]=my_pack($row, GOIP_ADD);
+			sendto_xchanged($send);
+			echo "OK";
+		}
+		else echo "ERROR group error!";
+	}
+
+}
 elseif($_REQUEST['set']=='disable' ||$_REQUEST['set']=='enable'){
 	
 	if($_REQUEST[sim]) {
@@ -187,18 +226,18 @@ elseif($_REQUEST['get']=="hbfail"){
 	}
 }
 elseif($_REQUEST['get']=='rbin'){
-        //if($_REQUEST[sig]) $where=" and csq=$_REQUEST[sig]";
-        if($_REQUEST['line']) $where.=" and line_name='$_REQUEST[line]'";
-        if($_REQUEST['sig']) $where.=" and csq='$_REQUEST[sig]'";
-        if($_REQUEST['op']) $where.=" and oper='$_REQUEST[op]'";
-        if($_REQUEST['lst']) $where.=" and line_status='$_REQUEST[lst]'";
-        if($_REQUEST['gst']) $where.=" and gsm_status='$_REQUEST[gst]'";
-        if($_REQUEST['state']) $where.=" and call_state='$_REQUEST[state]'";
-        $query=$db->query("select line_name,csq,oper,line_status,gsm_status,call_state from device_line where line_name != '' $where");
-        while($row=@$db->fetch_array($query)) {
-      //echo "$row[0] $row[1] $row[2] $row[3] $row[4] $row[5];\n";
-      echo $row[0].",".$row[1].",".$row[2].",".$row[3].",".$row[4].",".$row[5].";";
-     }
+	//if($_REQUEST[sig]) $where=" and csq=$_REQUEST[sig]";
+	if($_REQUEST['line']) $where.=" and line_name='$_REQUEST[line]'";
+	if($_REQUEST['sig']) $where.=" and csq='$_REQUEST[sig]'";
+	if($_REQUEST['op']) $where.=" and oper='$_REQUEST[op]'";
+	if($_REQUEST['lst']) $where.=" and line_status='$_REQUEST[lst]'";
+	if($_REQUEST['gst']) $where.=" and gsm_status='$_REQUEST[gst]'";
+	if($_REQUEST['state']) $where.=" and call_state='$_REQUEST[state]'";
+	$query=$db->query("select line_name,csq,oper,line_status,gsm_status,call_state from device_line where line_name != '' $where");
+	while($row=@$db->fetch_array($query)) {
+		//echo "$row[0] $row[1] $row[2] $row[3] $row[4] $row[5];\n";
+		echo $row[0].",".$row[1].",".$row[2].",".$row[3].",".$row[4].",".$row[5].";";
+	}
 }
 
 ?>
